pub struct LoginRequest {
pub credentials: Credentials,
pub client_id: Option<ClientId>,
}Fields
credentials: Credentialsclient_id: Option<ClientId>Trait Implementations
Sourceimpl Debug for LoginRequest
impl Debug for LoginRequest
Sourceimpl<'de> Deserialize<'de> for LoginRequest
impl<'de> Deserialize<'de> for LoginRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LoginRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LoginRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for LoginRequest
impl Serialize for LoginRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TS for LoginRequest
impl TS for LoginRequest
const EXPORT_TO: Option<&'static str>
Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
interface User { user_id: number, ... }.
This function will panic if the type has no declaration.Sourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten an type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn dependencies() -> Vec<Dependency>where
LoginRequest: 'static,
fn dependencies() -> Vec<Dependency>where
LoginRequest: 'static,
Information about types this type depends on.
This is used for resolving imports when exporting to a file.
Sourcefn transparent() -> bool
fn transparent() -> bool
true if this is a transparent type, e.g tuples or a list.This is used for resolving imports when using the
export! macro.Sourcefn name_with_type_args(args: Vec<String>) -> String
fn name_with_type_args(args: Vec<String>) -> String
Name of this type in TypeScript, with type arguments.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to a file.
The output file can be specified by annotating the type with
#[ts(export_to = ".."].
By default, the filename will be derived from the types name. Read moreSourcefn export_to(path: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_to(path: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to a file with a file with the specified path. This
function will ignore the
#[ts(export_to = "..)] attribute.Sourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,
Manually generate bindings for this type, returning a
This function does not format the output, even if the
String.This function does not format the output, even if the
format feature is enabled.Auto Trait Implementations
impl Freeze for LoginRequest
impl RefUnwindSafe for LoginRequest
impl Send for LoginRequest
impl Sync for LoginRequest
impl Unpin for LoginRequest
impl UnwindSafe for LoginRequest